@@ -22,7 +22,7 @@
 #define _PAC_PACMAN_H
 
 #ifndef PACVER
-#define PACVER    "2.7.7"
+#define PACVER    "2.7.8"
 #endif
 
 #ifndef PKGDIR
@@ -33,6 +33,10 @@
 #define PACCONF   "etc/pacman.conf"
 #endif
 
+#ifndef CACHEDIR
+#define CACHEDIR "var/cache/pacman/pkg"
+#endif
+
 /* Operations */
 #define PM_MAIN			1
 #define PM_ADD			2
